$set 14 #main

$ #RCRequiresArg
# fel: '-rc' krver ett argument\n
$ #DISPLAYRequiresArg
# fel: '-display' krver ett argument\n
$ #WarnDisplaySet
# varning: kunde inte stta variabeln 'DISPLAY'\n
$ #Usage
# Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
  -display <strng>\t\tanvnd skrmanslutning.\n\
  -rc <strng>\t\t\tanvnd alternativ resursfil.\n\
  -version\t\t\tvisa version och avsluta.\n\
  -info\t\t\t\tVisar nyttig information.\n\
  -log <filenamn>\t\t\tloggar utskriften till en fil.\n\
  -help\t\t\t\tvisa denna hjlptext och avsluta.\n\n
$ #CompileOptions
# Kompilerad med:\n\
  Avlusning\t\t\t%s\n\
  Interlacing:\t\t\t%s\n\
  Form:\t\t\t\t%s\n\
  Slit:\t\t\t\t%s\n\
  8bpp ordnad dithering:\t%s\n\n
